@@ -25,6 +25,6 @@ class GitProjects:
                 if repo.is_dirty():
                     dirty.append(os.path.basename(d))
             except InvalidGitRepositoryError:
-                pass
+                print(f'{d} if not a Git repository')
 
         return dirty
